@@ -1,11 +1,11 @@
 from dataclasses import dataclass
 from pathlib import Path
-from typing import List, Iterator
+from typing import Iterator, List, Tuple
 
 from datagen.components.scene import Scene
 
 # Older datasets scenes are named "environment_XXXXX".
-SCENE_FOLDER_NAME_PATTERNS = ["scene_*", "environment_*"]
+SCENE_FOLDER_NAME_PATTERNS = ["scene_*", "environment_*", "datapoint_*"]
 
 
 class CorruptedSourceError(ValueError):
@@ -33,7 +33,7 @@ class DataSource:
 
 @dataclass
 class SourcesRepository:
-    sources_paths: List[str]
+    sources_paths: Tuple[str]
 
     def get_all(self) -> Iterator[DataSource]:
         for path in self.sources_paths:
