@@ -18,7 +18,7 @@ class Scene:
         return [Camera(name=camera_name, scene_path=self.path) for camera_name in sorted(self._get_cameras_names())]
 
     def _get_cameras_names(self) -> List[str]:
-        return list(set(cam_dir.name for cam_dir in self.path.rglob("*camera*") if cam_dir.is_dir()))
+        return list(set(cam_dir.name for cam_dir in self.path.glob("*") if cam_dir.is_dir()))
 
     @property
     def datapoints(self) -> List[DataPoint]:
